package pps.core.prediction.service;

import cn.hutool.core.collection.CollUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.apache.commons.lang3.StringUtils;
import pps.cloud.prediction.service.IPlantPredictedPowerCloudService;
import pps.cloud.prediction.service.data.plant_predicted_power_data.DynamicQueryPlantPredictedPowerInput;
import pps.cloud.prediction.service.data.plant_predicted_power_data.DynamicQueryPlantPredictedPowerOutput;
import pps.core.prediction.entity.PlantPredictedPowerDataEnt;
import pps.core.prediction.entity.PlantPredictedPowerLongTermDataEnt;
import pps.core.prediction.mapper.PlantPredictedPowerDataMapper;
import pps.core.prediction.mapper.PlantPredictedPowerLongTermDataMapper;
import pps.core.prediction.service.data.wellhead_daily_production_situation.WellheadDailyProductionSituationJob;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.base.util.XCopyUtils;
import xstartup.data.XListResult;
import xstartup.data.XServiceResult;

import java.util.ArrayList;
import java.util.List;

/**
 * 光伏预测Cloud模块
 *
 * @author ZWT
 * @date 2023/09/13 19:05
 */
@XService
public class PlantPredictedPowerCloudServiceImpl implements IPlantPredictedPowerCloudService {

    /**
     * 光伏预测Cloud模块--条件查询时段发电量平均值
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult}<{@link DynamicQueryPlantPredictedPowerOutput}>
     */
    @Override
    public XListResult<DynamicQueryPlantPredictedPowerOutput> queryAveragePowerGenerationListByParam(XContext context, DynamicQueryPlantPredictedPowerInput input) {
        String plantId = input.getPlantId();
        List<String> plantIds = input.getPlantIds();
        String yearTime = input.getYearTime();
        String monthTime = input.getMonthTime();
        String startTime = input.getStartTime();
        String endTime = input.getEndTime();
        Integer dateType = input.getDateType();
        List list = null;
        if (CollUtil.isNotEmpty(plantIds)) {
            switch (dateType) {
                case 0:
                    PlantPredictedPowerLongTermDataMapper longTermDataMapper = context.getBean(PlantPredictedPowerLongTermDataMapper.class);
                    list = longTermDataMapper.selectList(
                            new QueryWrapper<PlantPredictedPowerLongTermDataEnt>()
                                    .select("hour_time",
                                            "min_time",
                                            "IFNULL( AVG( power ), 0 ) AS power",
                                            "STR_TO_DATE( CONCAT( hour_time, ':', min_time ), '%H:%i:%s' ) AS create_time")
                                    .lambda()
                                    .eq(StringUtils.isNotBlank(plantId), PlantPredictedPowerLongTermDataEnt::getPlantId, plantId)
                                    .in(PlantPredictedPowerLongTermDataEnt::getPlantId, plantIds)
                                    .eq(StringUtils.isNotBlank(yearTime), PlantPredictedPowerLongTermDataEnt::getYearTime, yearTime)
                                    .eq(StringUtils.isNotBlank(monthTime), PlantPredictedPowerLongTermDataEnt::getMonthTime, monthTime)
                                    .between(!StringUtils.isAnyBlank(startTime, endTime), PlantPredictedPowerLongTermDataEnt::getDataDate, startTime, endTime)
                                    .groupBy(PlantPredictedPowerLongTermDataEnt::getHourTime,
                                            PlantPredictedPowerLongTermDataEnt::getMinTime)
                                    .orderByAsc(PlantPredictedPowerLongTermDataEnt::getHourTime, PlantPredictedPowerLongTermDataEnt::getMinTime)
                    );
                    break;
                case 1:
                    PlantPredictedPowerDataMapper mapper = context.getBean(PlantPredictedPowerDataMapper.class);
                    list = mapper.selectList(
                            new QueryWrapper<PlantPredictedPowerDataEnt>()
                                    .select("hour_time",
                                            "min_time",
                                            "IFNULL( AVG( power ), 0 ) AS power",
                                            "STR_TO_DATE( CONCAT( hour_time, ':', min_time ), '%H:%i:%s' ) AS create_time")
                                    .lambda()
                                    .eq(StringUtils.isNotBlank(plantId), PlantPredictedPowerDataEnt::getPlantId, plantId)
                                    .in(PlantPredictedPowerDataEnt::getPlantId, plantIds)
                                    .eq(StringUtils.isNotBlank(yearTime), PlantPredictedPowerDataEnt::getYearTime, yearTime)
                                    .eq(StringUtils.isNotBlank(monthTime), PlantPredictedPowerDataEnt::getMonthTime, monthTime)
                                    .between(!StringUtils.isAnyBlank(startTime, endTime), PlantPredictedPowerDataEnt::getDataDate, startTime, endTime)
                                    .groupBy(PlantPredictedPowerDataEnt::getHourTime,
                                            PlantPredictedPowerDataEnt::getMinTime)
                                    .orderByAsc(PlantPredictedPowerDataEnt::getHourTime, PlantPredictedPowerDataEnt::getMinTime)
                    );
                    break;
                default:
            }
        }
        List<DynamicQueryPlantPredictedPowerOutput> outputs;
        if (CollUtil.isEmpty(list)) {
            outputs = new ArrayList<>(0);
        } else {
            outputs = XCopyUtils.copyNewList(list, DynamicQueryPlantPredictedPowerOutput.class);
        }
        return XListResult.success(outputs);
    }

    /**
     * 光伏预测Cloud模块--获取每小时平均发电量列表
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XListResult}<{@link DynamicQueryPlantPredictedPowerOutput}>
     */
    @Override
    public XListResult<DynamicQueryPlantPredictedPowerOutput> queryAveragePowerGenerationHourListByParam(XContext context, DynamicQueryPlantPredictedPowerInput input) {
        String plantId = input.getPlantId();
        List<String> plantIds = input.getPlantIds();
        String yearTime = input.getYearTime();
        String monthTime = input.getMonthTime();
        String startTime = input.getStartTime();
        String endTime = input.getEndTime();
        Integer dateType = input.getDateType();
        List list = null;
        if (CollUtil.isNotEmpty(plantIds)) {
            switch (dateType) {
                case 0:
                    PlantPredictedPowerLongTermDataMapper longTermDataMapper = context.getBean(PlantPredictedPowerLongTermDataMapper.class);
                    list = longTermDataMapper.selectList(
                            new QueryWrapper<PlantPredictedPowerLongTermDataEnt>()
                                    .select("CONCAT( hour_time, ':', REPLACE ( min_time, ':00', '' ) ) AS hour_time",
                                            "IFNULL( AVG( power ), 0 ) AS power")
                                    .lambda()
                                    .eq(StringUtils.isNotBlank(plantId), PlantPredictedPowerLongTermDataEnt::getPlantId, plantId)
                                    .in(PlantPredictedPowerLongTermDataEnt::getPlantId, plantIds)
                                    .eq(StringUtils.isNotBlank(yearTime), PlantPredictedPowerLongTermDataEnt::getYearTime, yearTime)
                                    .eq(StringUtils.isNotBlank(monthTime), PlantPredictedPowerLongTermDataEnt::getMonthTime, monthTime)
                                    .between(!StringUtils.isAnyBlank(startTime, endTime), PlantPredictedPowerLongTermDataEnt::getDataDate, startTime, endTime)
                                    .groupBy(PlantPredictedPowerLongTermDataEnt::getHourTime, PlantPredictedPowerLongTermDataEnt::getMinTime)
                                    .orderByAsc(PlantPredictedPowerLongTermDataEnt::getHourTime, PlantPredictedPowerLongTermDataEnt::getMinTime)
                    );
                    break;
                case 1:
                    PlantPredictedPowerDataMapper mapper = context.getBean(PlantPredictedPowerDataMapper.class);
                    list = mapper.selectList(
                            new QueryWrapper<PlantPredictedPowerDataEnt>()
                                    .select("CONCAT( hour_time, ':', REPLACE ( min_time, ':00', '' ) ) AS hour_time",
                                            "IFNULL( AVG( power ), 0 ) AS power")
                                    .lambda()
                                    .eq(StringUtils.isNotBlank(plantId), PlantPredictedPowerDataEnt::getPlantId, plantId)
                                    .in(PlantPredictedPowerDataEnt::getPlantId, plantIds)
                                    .eq(StringUtils.isNotBlank(yearTime), PlantPredictedPowerDataEnt::getYearTime, yearTime)
                                    .eq(StringUtils.isNotBlank(monthTime), PlantPredictedPowerDataEnt::getMonthTime, monthTime)
                                    .between(!StringUtils.isAnyBlank(startTime, endTime), PlantPredictedPowerDataEnt::getDataDate, startTime, endTime)
                                    .groupBy(PlantPredictedPowerDataEnt::getHourTime, PlantPredictedPowerDataEnt::getMinTime)
                                    .orderByAsc(PlantPredictedPowerDataEnt::getHourTime, PlantPredictedPowerDataEnt::getMinTime)
                    );
                    break;
                default:
            }
        }
        List<DynamicQueryPlantPredictedPowerOutput> outputs;
        if (CollUtil.isEmpty(list)) {
            outputs = new ArrayList<>(0);
        } else {
            outputs = XCopyUtils.copyNewList(list, DynamicQueryPlantPredictedPowerOutput.class);
        }
        return XListResult.success(outputs);
    }

    /**
     * 日耗电日产液信息定时任务
     *
     * @param context 上下文
     * @return {@link XServiceResult}
     */
    @Override
    public XServiceResult wellTechDailyJob(XContext context) {
        String s = "{\n" +
                "\t\"status\": 100,\n" +
                "\t\"msg\": \"执行成功！\",\n" +
                "\t\"data\": [\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"王侧11-8\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 40.37,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.2,\n" +
                "\t\t\t\"starthours\": 900,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塞侧29-4\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 39.71,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.04,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山31-14\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 78.33,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.69,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山33-13\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 56.01,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 3.74,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山33-14\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": null,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.8,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山34-13\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": null,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 4.6,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山36-13\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 25.09,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 4.49,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山39-12\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 25.36,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.29,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山40-11\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 26.54,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.19,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山41-9\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 68.46,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 0.58,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山43-5\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 16.67,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.03,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午249-9\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 18.71,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.44,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午252-9\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 42.02,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 6.65,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午291\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": null,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.36,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午侧249-8\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 206.96,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 6.01,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午平231-04\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 81.51,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 5.9,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山30-15\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 25.11,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.31,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山35-12\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 189.94,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.41,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山38-13\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 25.52,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.71,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山39-11\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 19.98,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.73,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山41-6\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 55.08,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 5.04,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午250-10\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 62.34,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 6.71,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午251-10\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 39.17,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 8.26,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山37-11\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 40.29,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 4.52,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山33-15\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 236.27,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.92,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"午222-210X\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 43.76,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 0.93,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山37-13\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 17.33,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.85,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山35-14\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": null,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 0.66,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山35-15\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 169.45,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.61,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山38-11\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 34.55,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 3.57,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山42-9\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 27.9,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.29,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"山32-13\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": null,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 0,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"成36-46\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 65.95,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.79,\n" +
                "\t\t\t\"starthours\": 40,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塬49-90\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 178,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 4.99,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塬46-89\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 56.22,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 0.4,\n" +
                "\t\t\t\"starthours\": 8,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塬46-93\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 86.54,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.88,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塬32-92\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 44.45,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.53,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"成37-46\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 59.16,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 0.81,\n" +
                "\t\t\t\"starthours\": 44,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塬46-90\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 74.08,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 1.85,\n" +
                "\t\t\t\"starthours\": 44,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"成63-10\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 68.32,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 2.59,\n" +
                "\t\t\t\"starthours\": 40,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t},\n" +
                "\t\t{\n" +
                "\t\t\t\"welL_NAME\": \"塬46-92\",\n" +
                "\t\t\t\"caL_DATE\": \"2024-03-15T00:00:00\",\n" +
                "\t\t\t\"poweR_CONSUME_DAILY\": 60.54,\n" +
                "\t\t\t\"reaL_LIQUID_DAILY\": 3.62,\n" +
                "\t\t\t\"starthours\": 0,\n" +
                "\t\t\t\"status\": null,\n" +
                "\t\t\t\"next_ExecDate\": \"0001-01-01T00:00:00\"\n" +
                "\t\t}\n" +
                "\t]\n" +
                "}";
        JSONObject jsonObject = JSON.parseObject(s);
        String data = jsonObject.getString("data");
        List<WellheadDailyProductionSituationJob> wellheadDailyProductionSituationJobs = JSON.parseArray(data, WellheadDailyProductionSituationJob.class);
        return XServiceResult.OK;
    }
}
